<?php
if ( ! function_exists( 'add_action' ) ) {
	echo "Hi there!  I'm just a plugin, not much I can do when called directly.";
	exit;
}

require_once( "jpibfi-validation.php" );

//HTML HELPERS

function jpibfi_print_error_class( $error_array, $field_name ) {
	if ( ! empty( $error_array ) && array_key_exists( $field_name, $error_array ) )
		echo "class='error-border'";
}

function jpibfi_print_error_div( $div_id, $error_array, $field_name, $message ) {
	$display_message = "";
	if ( ! empty( $error_array ) && array_key_exists( $field_name, $error_array ) )
		$display_message = "style='display:block;'";
	printf( '<div id="%s" class="error-info" %s>%s</div>', $div_id, $display_message, $message );
}

//END HTML HELPERS

//Prints out the admin page
function jpibfi_print_admin_page() {
	global $jpibfi_admin_basic_options_name;
	global $jpibfi_admin_advanced_options_name;

	$dev_options          = jpibfi_get_basic_options();
	$advanced_dev_options = jpibfi_get_advanced_options();

	$errors = array();

	if ( isset( $_POST['update_jQuery_Pin_It_Button_For_Images'] ) ) {
		//security check
		if ( ! wp_verify_nonce( $_POST['jpibfi_nonce'], 'jpibfi_admin_settings' ) )
			die( 'Security alert' );



		if ( ! jpibfi_contains_css_class_names_or_empty( $_POST['disabled_classes'] ) )
			$errors['disabled_classes'] = true;

		if ( ! jpibfi_contains_css_class_names_or_empty( $_POST['enabled_classes'] ) )
			$errors['enabled_classes'] = true;

		if ( ! jpibfi_is_numeric_or_empty( $_POST['custom_image_height'] ) )
			$errors['custom_image_height'] = true;

		if ( ! jpibfi_is_numeric_or_empty( $_POST['custom_image_width'] ) )
			$errors['custom_image_width'] = true;

		//rewrite settings that came from the POST request
		$dev_options['image_selector']     = sanitize_text_field( $_POST['image_selector'] );
		$dev_options['compatibility_mode'] = $_POST['compatibility_mode'] == '1' ? '1' : '0';
		$dev_options['transparency_value'] =
				$dev_options['compatibility_mode'] == '0' ? $_POST['standard_transparency'] : $_POST['compatibility_transparency'];
		$dev_options['disabled_classes']   = $_POST['disabled_classes'];
		$dev_options['enabled_classes']    = $_POST['enabled_classes'];
		$dev_options['description_option'] = $_POST['description_option'];

		$dev_options['use_custom_image']    = $_POST['use_custom_image'] == "1" ? "1" : "0";
		$dev_options['custom_image_url']    = $_POST['custom_image_url'];
		$dev_options['custom_image_height'] = $_POST['custom_image_height'];
		$dev_options['custom_image_width']  = $_POST['custom_image_width'];


		if ( $dev_options['compatibility_mode'] == '0' )
			if ( ! is_numeric( $dev_options['transparency_value'] ) || ( $dev_options['transparency_value'] < 0.0 ) || ( $dev_options['transparency_value'] > 1.0 ) )
				$errors['transparency_value'] = true;

		$advanced_dev_options['on_home']     = $_POST['on_home'] == '1' ? '1' : '0';
		$advanced_dev_options['on_page']     = $_POST['on_page'] == '1' ? '1' : '0';
		$advanced_dev_options['on_single']   = $_POST['on_single'] == '1' ? '1' : '0';
		$advanced_dev_options['on_category'] = $_POST['on_category'] == '1' ? '1' : '0';

		if ( 0 == count( $errors ) ) { //save only if there are no errors
			update_option( $jpibfi_admin_basic_options_name, $dev_options );
			update_option( $jpibfi_admin_advanced_options_name, $advanced_dev_options );
			?>
		<p class="jpibfi-success-message"><?php _e( "Settings Updated.", "jpibfi" );?></p>
		<?php
		}
		else { //otherwise inform that there are some errors
			?>
		<p class='jpibfi-error-message'><?php _e( "Error. Settings not updated. Look for details below.", "jpibfi" ); ?></p>
		<?php
		}
	}
?>
<div class="wrap">
	<h2>jQuery Pin It Button For Images</h2>

	<form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
		<?php wp_nonce_field( "jpibfi_admin_settings", 'jpibfi_nonce' ); ?>
		<h3>Plugin settings</h3>

		<table class="settings-table">
			<tbody>
			<tr>
				<th scope="row"><label for="image_selector">Image selector</label></th>
				<td>
					<input type="text" id="image_selector" name="image_selector"
								 value="<?php echo esc_attr( $dev_options['image_selector'] );?>" />

					<p class="description">jQuery selector for all the images that should have the "Pin it" button. Set
						the value to <a href="#" class="jpibfi_selector_option">div.jpibfi_container img</a> if you want
						the "Pin it" button to appear only on images in content or
						<a href="#" class="jpibfi_selector_option">img</a>
						to appear on all images on site (including sidebar, header and footer). If you know a thing or
						two about jQuery, you might use your own selector.
						<a href="http://api.jquery.com/category/selectors/" target="_blank">Click here</a> to read
						about jQuery selectors.</p>
				</td>
			</tr>
			<tr>
				<th scope="row"><label for="disabled_classes">Disabled classes</label></th>
				<td>
					<div class="left-element">
						<textarea id="disabled_classes"
											name="disabled_classes" <?php jpibfi_print_error_class( $errors, 'disabled_classes' ); ?>><?php echo esc_attr( $dev_options['disabled_classes'] );?></textarea>
					</div>
					<?php jpibfi_print_error_div( "disabled_classes_error", $errors, "disabled_classes",
						"Error. Please change this setting and try submitting again." ); ?>

					<p class="description">Pictures with these CSS classes won't show the "Pin it" button. Please
						separate multiple classes with semicolons. Spaces are not accepted.</p>
				</td>
			</tr>
			<tr>
				<th scope="row"><label for="enabled_classes">Enabled classes</label></th>
				<td>
					<div class="left-element">
						<textarea id="enabled_classes"
											name="enabled_classes" <?php jpibfi_print_error_class( $errors, 'enabled_classes' ); ?>><?php echo $dev_options['enabled_classes'];?></textarea>
					</div>
					<?php jpibfi_print_error_div( "enabled_classes_error", $errors, "enabled_classes",
					"Error. Please change this setting and try submitting again." ); ?>

					<p class="description">Pictures with these CSS classes will show the "Pin it" button. Please
						separate multiple classes with semicolons. If this field is empty, images with any (besides
						disabled ones) classes will show the Pin It button.</p>
				</td>
			</tr>
			<tr>
				<th scope="row"><label for="description_option">Description source</label></th>
				<td>
					<select id="description_option" name="description_option">
						<option value="1" <?php if ( "1" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>
							Page title
						</option>
						<option value="2" <?php if ( "2" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>
							Page description
						</option>
						<option value="3" <?php if ( "3" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>
							Picture title or alt attributes
						</option>
					</select>

					<p class="description">From where the Pinterest message should be taken.</p>
				</td>
			</tr>
			<tr>
				<th scope="row"><label for="compatibility_mode">Transparency</label></th>
				<td>
					<select name="compatibility_mode" id="compatibility_mode">
						<option value="0" <?php echo "0" == $dev_options['compatibility_mode'] ? "selected='selected'" : "";?>>
							Standard mode
						</option>
						<option value="1" <?php echo "1" == $dev_options['compatibility_mode'] ? "selected='selected'" : "";?>>
							IE7 Compatibility mode
						</option>
					</select>

					<p id="standard_mode_transparency" <?php echo "1" == $dev_options['compatibility_mode'] ? "style='display:none'" : "";?>>
						<label for="standard_transparency">Choose transparency (between 0.00 and 1.00)</label><br />
						<input type="text" id="standard_transparency" name="standard_transparency"
									 value="<?php echo $dev_options['transparency_value'];?>" <?php jpibfi_print_error_class( $errors, 'transparency_value' ); ?>/>

						<?php jpibfi_print_error_div( "standard_transparency_error", $errors, "transparency_value",
						"The number is not valid. Please change the value and try submitting again." ); ?>

					</p>

					<p id="compatibility_mode_transparency" <?php echo "0" == $dev_options['compatibility_mode'] ? "style='display:none'" : "";?>>
						<label for="compatibility_transparency">Choose transparency</label><br />
						<select name="compatibility_transparency" id="compatibility_transparency">
							<?php for ( $i = 0; $i <= 1; $i += 0.1 ): ?>
							<option value="<?php echo $i;?>" <?php if ( round( $i, 1 ) == round( $dev_options['transparency_value'], 1 ) ) echo "selected='selected'"; ?>>
								<?php echo $i;?>
							</option>
							<?php endfor; ?>
						</select>
					</p>
					<p class="description">If you want the plugin to work properly on IE7, meaning the image will become
						transparent on hover, you need to use IE7 Compatibility mode.</p>
				</td>
			</tr>
			<tr>
				<th scope="row"><label>Use custom Pinterest button</label></th>
				<td>
					<input type="checkbox" id="use_custom_image" name="use_custom_image" value="1" <?php echo "1" == $dev_options["use_custom_image"] ? "checked='checked'" : "" ?> />
					<label class="chbox-label" for="use_custom_image">Use custom image</label><br />

					<p><label for="custom_image_url">URL address of the image</label><br />
						<input type="text" id="custom_image_url" name="custom_image_url" value="<?php echo $dev_options["custom_image_url"]; ?>" />
					</p>

					<div class="left-element" style="clear:both;">
						<label for="custom_image_height">Height of the image (in pixels)</label><br />
						<input type="text" id="custom_image_height" name="custom_image_height" value="<?php echo $dev_options["custom_image_height"]; ?>"
								<?php jpibfi_print_error_class( $errors, 'custom_image_height' ); ?> />
					</div>
					<?php jpibfi_print_error_div( "custom_image_height_error", $errors, "custom_image_height",
					"Must be either blank or a number" ); ?>

					<div class="left-element" style="clear:both;">
						<label for="custom_image_width">Width of the image (in pixels)</label><br />
						<input type="text" id="custom_image_width" name="custom_image_width" value="<?php echo $dev_options["custom_image_width"]; ?>"
								<?php jpibfi_print_error_class( $errors, 'custom_image_width' ); ?> />
					</div>
					<?php jpibfi_print_error_div( "custom_image_width_error", $errors, "custom_image_width",
					"Must be either blank or a number" ); ?>

					<p class="description">Check the
						<b>Use custom image</b> checkbox, specify image's URL, height and width to use your own Pinterest button design.
					</p>
				</td>
			</tr>
			<tr>
				<th scope="row"><label>On which pages the "Pin it" button should be shown</label></th>
				<td>
					<input type="checkbox" id="on_home"
								 name="on_home" <?php echo "1" == $advanced_dev_options['on_home'] ? "checked='checked'" : "";?> value="1" /><label class="chbox-label" for="on_home"> Home page</label><br />
					<input type="checkbox" id="on_page"
								 name="on_page" <?php echo "1" == $advanced_dev_options['on_page'] ? "checked='checked'" : "";?> value="1" /><label class="chbox-label" for="on_page"> Pages</label><br />
					<input type="checkbox" id="on_single"
								 name="on_single" <?php echo "1" == $advanced_dev_options['on_single'] ? "checked='checked'" : "";?> value="1" /><label class="chbox-label" for="on_single"> Single posts</label><br />
					<input type="checkbox" id="on_category"
								 name="on_category" <?php echo "1" == $advanced_dev_options['on_category'] ? "checked='checked'" : "";?> value="1" /><label class="chbox-label" for="on_category"> Category pages</label>

					<p class="description">Check on which pages you want the Pinterest button to show up.</p>
				</td>
			</tr>
			<tr>
				<th scope="row"></th>
				<td>
					<input id="submit_form" type="submit" style="padding:7px; float:right;"
								 name="update_jQuery_Pin_It_Button_For_Images"
								 value="<?php _e( 'Update Settings', 'jQuery_Pin_It_Button_For_Images' ) ?>" />
				</td>
			</tr>
			</tbody>
		</table>
	</form>
</div>
<?php
}
?>