<?php
/*
Plugin Name: jQuery Pin It Button For Images
Plugin URI: http://wordpress.org/extend/plugins/jquery-pin-it-button-for-images/
Description: Highlights images on hover and adds a "Pin It" button over them for easy pinning.
Author: Marcin Skrzypiec
Version: 0.9.2
Author URI: http://profiles.wordpress.org/mrsztuczkens
*/

if ( ! function_exists( 'add_action' ) ) {
	echo "Hi there!  I'm just a plugin, not much I can do when called directly.";
	exit;
}

define( "JPIBFI_VERSION", "0.9.2" );

require_once( "jpibfi-validation.php" );
require_once( "jpibfi-admin.php" );

$jpbfi_description_option_values   = array( '1', '2', '3' );
$jpibfi_admin_basic_options_name    = "jptbfi_options";
$jpibfi_admin_advanced_options_name = "jptbfi_advanced_options";
$jpibfi_post_metadata_name          = "jpibfi_meta";


//Returns an array of basic admin options, updates settings if necessary
function jpibfi_get_basic_options() {
	global $jpibfi_admin_basic_options_name, $jpbfi_description_option_values;

	$admin_options = array(
		'image_selector'      => 'div.jpibfi_container img',
		'disabled_classes'    => 'nopin;wp-smiley',
		'description_option'  => $jpbfi_description_option_values[0],
		'enabled_classes'     => '',
		'compatibility_mode'  => '0',
		'transparency_value'  => '0.5',
		'use_custom_image'    => '0',
		'custom_image_url'    => '',
		'custom_image_height' => '',
		'custom_image_width'  => ''
	);

	$dev_options = get_option( $jpibfi_admin_basic_options_name );

	$changes_in_db = count( $admin_options ) != count( $dev_options ); //if arrays aren't of the same length, changes in db needed

	//invalid values need to be corrected and saved in db
	if ( ! empty( $dev_options ) ) {
		foreach ( $dev_options as $key => $option ) {
			switch ( $key ) {
				case "image_selector": //no constraints
				case "custom_image_url":
					$admin_options[$key] = $option;
					break;
				case "disabled_classes": //contains list of css classes or is empty
				case "enabled_classes":
					if ( jpibfi_contains_css_class_names_or_empty( $option ) )
						$admin_options[$key] = $option;
					else
						$changes_in_db = true;
					break;
				case "description_option":
					if ( in_array( $option, $jpbfi_description_option_values ) )
						$admin_options[$key] = $option;
					else
						$changes_in_db = true;
					break;
				case "compatibility_mode": //0 or 1 values
				case "use_custom_image":
					if ( strcmp( $option, '0' ) != 0 && strcmp( $option, '1' ) != 0 ) //invalid value in database
						$changes_in_db = true;
					else
						$admin_options[$key] = $option;
					break;
				case "transparency_value": //between 0 and 1
					if ( ! is_numeric( $option ) || ( $option < 0 ) || ( $option > 1 ) )
						$changes_in_db = true;
					else
						$admin_options[$key] = $option;
					break;
				case "custom_image_width": //numeric value or empty
				case "custom_image_height":
					if ( jpibfi_is_numeric_or_empty( $option ) )
						$admin_options[$key] = $option;
					else
						$changes_in_db = true;
					break;
			}
		}
	}
	else {
		$changes_in_db = true;
	}

	//if something changed in the database, we need to save it
	if ( $changes_in_db )
		update_option( $jpibfi_admin_basic_options_name, $admin_options );

	return $admin_options;
}

//End function jpibfi_get_basic_options()

//Returns an array of advanced admin options, updates settings if necessary
function jpibfi_get_advanced_options() {
	global $jpibfi_admin_advanced_options_name;

	$admin_options = array(
		'on_home'     => '1',
		'on_single'   => '1',
		'on_page'     => '1',
		'on_category' => '1'
	);

	$dev_options   = get_option( $jpibfi_admin_advanced_options_name );
	$changes_in_db = count( $admin_options ) != count( $dev_options ); //if arrays aren't of the same length, changes in db needed

	foreach ( $admin_options as $setting_name => $setting_value ) {
		if ( array_key_exists( $setting_name, $dev_options ) )
			$admin_options[$setting_name] = $dev_options[$setting_name];
	}

	//if something changed in the database, we need to save it
	if ( $changes_in_db )
		update_option( $jpibfi_admin_advanced_options_name, $admin_options );
	return $admin_options;
}
//


//returns false if plugin shouldn't be added to certain post based on metadata, otherwise true
function jpibfi_add_plugin_to_post( $post_id ) {
	global $jpibfi_post_metadata_name;
	$post_meta = get_post_meta( $post_id, $jpibfi_post_metadata_name, true );
	if ( ! empty( $post_meta ) && array_key_exists( 'jpibfi_disable_for_post', $post_meta ) && $post_meta['jpibfi_disable_for_post'] == '1' )
		return false;
	return true;
}

//Returns true if plugin should be added to a certain page
function jpibfi_add_plugin() {
	global $post;
	$advanced_settings = jpibfi_get_advanced_options();

	if ( is_front_page() )
		return $advanced_settings['on_home'] == "1";
	else if ( is_single() )
		return $advanced_settings['on_single'] == "1" ? jpibfi_add_plugin_to_post( $post->ID ) : false;
	else if ( is_page() )
		return $advanced_settings['on_page'] == "1" ? jpibfi_add_plugin_to_post( $post->ID ) : false;
	else if ( is_category() )
		return $advanced_settings['on_category'] == "1";
	return true;
}

//fire it when activating the plugin - add all necessary db entries
function jpibfi_init_plugin() {
	jpibfi_get_basic_options();
	jpibfi_get_advanced_options();
}

//Adds all necessary scripts
function jpibfi_add_plugin_scripts() {
	if ( ! ( jpibfi_add_plugin() ) )
		return;
	// Adding my custom js, dependent on jquery
	wp_enqueue_script( 'jquery-pin-it-button-script', plugins_url( '/js/script.min.js', __FILE__ ), array( 'jquery' ), JPIBFI_VERSION, false );
	// Registering my custom style
	wp_register_style( 'jquery-pin-it-button-style', plugins_url( '/css/style.css', __FILE__ ), array(), JPIBFI_VERSION, 'all' );
	//Enqueue the style
	wp_enqueue_style( 'jquery-pin-it-button-style' );
}

function jpibfi_footer_action() {
	if ( !jpibfi_add_plugin() )
		return;

	$dev_options     = jpibfi_get_basic_options();
	$enabled_classes = $dev_options['enabled_classes'] ? ", enabled_classes:'" . $dev_options['enabled_classes'] . "'" : "";

	?>
	<script type="text/javascript">
		jQuery(document).ready(function ($) {
			$('.jpibfi').parent('div').addClass('jpibfi_container');
			jpibfi_pinit({
				image_selector:'<?php echo $dev_options['image_selector'];?>',
				disabled_classes:'<?php echo $dev_options['disabled_classes'];?>',
				description_option:'<?php echo $dev_options['description_option'];?>'
				<?php echo $enabled_classes;?>
			});
		});
	</script>
<?php
}

function jpibfi_print_header_style_action() {
	if ( ! ( jpibfi_add_plugin() ) )
		return;

	$dev_options = jpibfi_get_basic_options();

	if ( $dev_options['compatibility_mode'] == '0' )
		$css = 'background-color: rgba(255, 255, 255, ' . $dev_options['transparency_value'] . ');';
	else
		$css = "background: url('" .
				plugins_url( '/images/transparency/' .
						str_replace( '.', '_', $dev_options['transparency_value'] ) . '.png', __FILE__ ) . "') repeat;";

	if ( $dev_options['use_custom_image'] == "1" ) {
		$width  = $dev_options['custom_image_width'];
		$height = $dev_options['custom_image_height'];
		$url    = $dev_options['custom_image_url'];
	}
	else {
		$width  = 65;
		$height = 41;
		$url    = plugins_url( '/images/pinit-button.png', __FILE__ );
	}

	?>
<style type="text/css">
	.pinit .pinit-overlay { <?php echo $css; ?>    }

	.pinit .pinit-overlay a {
		<?php printf( 'width:%spx; height:%spx; background:transparent url("%s") no-repeat 0 0;',
		$width, $height, $url ); ?>
	}
</style>
<?php
}

function jpibfi_print_hidden_field_script( $content ) {
	if ( ! jpibfi_add_plugin() )
		return $content;
	return "<input class='jpibfi' type='hidden' />" . $content;
}

//ADMIN PAGE CODE

//add admin scripts
function jpibfi_add_admin_site_scripts() {
	wp_register_style( 'jquery-pin-it-button-admin-style', plugins_url( '/css/admin.css', __FILE__ ), array(), JPIBFI_VERSION, 'all' );
	wp_enqueue_style( 'jquery-pin-it-button-admin-style' );
	wp_enqueue_script( 'jquery-pin-it-button-script', plugins_url( '/js/admin.js', __FILE__ ), array( 'jquery' ), JPIBFI_VERSION, false );
}




//End function print_admin_page()

function jpibfi_print_admin_page_action() {
	$page = add_options_page( 'jQuery Pin It Button For Images', 'jQuery Pin It Button For Images', 9, basename( __FILE__ ), 'jpibfi_print_admin_page' );
	add_action( 'admin_print_styles-' . $page, 'jpibfi_add_admin_site_scripts' );
}

function jpibfi_plugin_settings_filter( $links ) {
	$settings_link = '<a href="options-general.php?page=jquery-pin-it-button-for-images.php">Settings</a>';
	array_unshift( $links, $settings_link );
	return $links;
}

//END ADMIN PAGE CODE

//POST EDITOR CODE

function jpibfi_add_meta_box() {
	//for posts
	add_meta_box(
		'jpibfi_settings_id', // this is HTML id of the box on edit screen
		'jQuery Pin It Button for Images - Settings', // title of the box
		'jpibfi_print_meta_box', // function to be called to display the checkboxes, see the function below
		'post', // on which edit screen the box should appear
		'side', // part of page where the box should appear
		'default' // priority of the box
	);

	//for pages
	add_meta_box(
		'jpibfi_settings_id',
		'jQuery Pin It Button for Images - Settings',
		'jpibfi_print_meta_box',
		'page',
		'side',
		'default'
	);
}

// display the metabox
function jpibfi_print_meta_box( $post, $metabox ) {
	global $jpibfi_post_metadata_name;

	wp_nonce_field( plugin_basename( __FILE__ ), 'jpibfi_nonce' );

	$post_meta = get_post_meta( $post->ID, $jpibfi_post_metadata_name, true );
	if ( isset( $post_meta ) && isset( $post_meta['jpibfi_disable_for_post'] ) && $post_meta['jpibfi_disable_for_post'] == '1' )
		$checked_message = 'checked="checked"';
	else
		$checked_message = '';

	echo '<input type="checkbox" id="jpibfi_disable_for_post" name="jpibfi_disable_for_post" value="1"'
			. $checked_message . ' /><label for="jpibfi_disable_for_post"> Disable "Pin it" button for this post (works only on single pages/posts)</label><br />';
}

function jpibfi_save_meta_data( $post_id ) {
	global $jpibfi_post_metadata_name;

	// check if this isn't an auto save
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
		return;
	// security check = updating possible only using post edit form
	if ( ! wp_verify_nonce( $_POST['jpibfi_nonce'], plugin_basename( __FILE__ ) ) )
		return;
	//check user's permissions
	if ( ! current_user_can( 'edit_post', $post_id ) )
		return;

	$post_meta = array( 'jpibfi_disable_for_post' => '0' );
	// now store data in custom fields based on checkboxes selected
	$post_meta['jpibfi_disable_for_post'] =
			isset( $_POST['jpibfi_disable_for_post'] ) && $_POST['jpibfi_disable_for_post'] == '1' ? '1' : '0';

	if ( $post_meta['jpibfi_disable_for_post'] == '1' )
		update_post_meta( $post_id, $jpibfi_post_metadata_name, $post_meta );
	else
		delete_post_meta( $post_id, $jpibfi_post_metadata_name );
}

//END POST EDITOR CODE

//fire it when the plugin is deleted
function jpibfi_uninstall_plugin() {
	global $jpibfi_admin_basic_options_name, $jpibfi_admin_advanced_options_name, $jpibfi_post_metadata_name;

	//delete all added options
	delete_option( $jpibfi_admin_basic_options_name );
	delete_option( $jpibfi_admin_advanced_options_name );

	//delete added metadata from all posts
	delete_post_meta_by_key( $jpibfi_post_metadata_name );
}

//Actions and Filters

	register_activation_hook( __FILE__, 'jpibfi_init_plugin' );
	register_uninstall_hook( __FILE__, 'jpibfi_uninstall_plugin' );
	//Actions
	add_action( 'wp_enqueue_scripts', 'jpibfi_add_plugin_scripts' );
	add_action( 'admin_menu', 'jpibfi_print_admin_page_action' );
	add_action( 'wp_footer', 'jpibfi_footer_action' );
	add_action( 'wp_head', 'jpibfi_print_header_style_action' );
	add_action( 'add_meta_boxes', 'jpibfi_add_meta_box' );
	add_action( 'save_post', 'jpibfi_save_meta_data' );

	//Filters
	$plugin = plugin_basename( __FILE__ );
	add_filter( "plugin_action_links_$plugin", 'jpibfi_plugin_settings_filter' );
	add_filter( "the_content", 'jpibfi_print_hidden_field_script' );

?>